# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.get_events200_response_pagination import GetEvents200ResponsePagination  # noqa: E501
from onelogin.rest import ApiException

class TestGetEvents200ResponsePagination(unittest.TestCase):
    """GetEvents200ResponsePagination unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetEvents200ResponsePagination
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetEvents200ResponsePagination`
        """
        model = onelogin.models.get_events200_response_pagination.GetEvents200ResponsePagination()  # noqa: E501
        if include_optional :
            return GetEvents200ResponsePagination(
                before_cursor = 'null', 
                after_cursor = 'xWNjb3VudF9pZDo6OjUzNDEzLS0jI2lkOjo6OTA0MjU3NTQ2', 
                previous_link = 'null', 
                next_link = 'https://your-api-subdomain.onelogin.com/api/1/events?after_cursor=xWNjb3VudF9pZDo6OjUzNDEzLS0jI2lkOjo6OTA0MjU3NTQ2'
            )
        else :
            return GetEvents200ResponsePagination(
        )
        """

    def testGetEvents200ResponsePagination(self):
        """Test GetEvents200ResponsePagination"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
