# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.revoke_tokens_request import RevokeTokensRequest  # noqa: E501
from onelogin.rest import ApiException

class TestRevokeTokensRequest(unittest.TestCase):
    """RevokeTokensRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RevokeTokensRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RevokeTokensRequest`
        """
        model = onelogin.models.revoke_tokens_request.RevokeTokensRequest()  # noqa: E501
        if include_optional :
            return RevokeTokensRequest(
                access_token = 'xx508xx63817x752xx74004x30705xx92x58349x5x78f5xx34x8x614xxxx1451'
            )
        else :
            return RevokeTokensRequest(
                access_token = 'xx508xx63817x752xx74004x30705xx92x58349x5x78f5xx34x8x614xxxx1451',
        )
        """

    def testRevokeTokensRequest(self):
        """Test RevokeTokensRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
