# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class Verb(str, Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """

    LOG_IN = 'log-in'
    LOG_OUT = 'log-out'
    LOG_IN_DENIED = 'log-in-denied'
    AUTHENTICATION_CHALLENGE = 'authentication-challenge'
    AUTHENTICATION_CHALLENGE_PASS = 'authentication-challenge-pass'
    AUTHENTICATION_CHALLENGE_FAIL = 'authentication-challenge-fail'

